###################################################################################################
# Legislative Organization and Political Representation ###########################################
# Data Assembly File ##############################################################################
# Michael Olson and Jon Rogowski ##################################################################
###################################################################################################

###################################################################################################
# working directory and packages ##################################################################
###################################################################################################

  require(stringr)
  require(readxl)
  require(haven)
  require(tidyr)
  require(dplyr)
  require(foreign)
  require(DataCombine)
    # we'll also use plyr for the rename function but it competes with dplyr, so we'll just call
    # it when we use it

###################################################################################################  
# load, clean, and process committee membership data ##############################################
###################################################################################################

# load committee membership data (from charles stewart, pieced together by jon)

  committees <- as.data.frame(read_dta("./raw_data/house_comm_membership.dta"))
  
    committees <- committees[committees$name!="[Vacant]",] # this only drops one observation
    
    committees <- committees[committees$cong<=113 & committees$cong>=81,]
      # this includes extra congresses that we only include for lags/leads; we limit the 
      # time frame here to save some grief with data cleaning

# merge in states and districts for a lot of folks who are some reason missing in CS's committee assignment file
# this new file is just his file of members from 103 - 115

  cs_fix <- as.data.frame(readxl::read_excel("./raw_data/house_members_103-115-2.xlsx",skip = 1))
  
    cs_fix <- cs_fix[cs_fix$cong<=113,c("id","name","district","state_ic","cong")] # this file has some extra info we don't use
    
    cs_fix <- plyr::rename(cs_fix,replace=c("id"="icpsr","district"="district_fixer")) 
    
    cs_fix <- cs_fix[!is.na(cs_fix$name),] # data has two mysterious missing rows
    
    # fix a few folks' info in this file so they merge nicely into the committees data
    
    cs_fix[cs_fix$name=="Clawson, Curt","icpsr"] <- 21377
    cs_fix[cs_fix$name=="Rooney III, Laurence F. (Francis)","icpsr"] <- 21742
    cs_fix[cs_fix$name=="Garrett Jr., Thomas A.","icpsr"] <- 21721
    cs_fix[cs_fix$name=="Tauzin, W. J. (Billy)" & cs_fix$icpsr==94679,"icpsr"] <- 14679
    cs_fix[cs_fix$name=="Molinari, Susan" & cs_fix$icpsr==15639,"icpsr"] <- 14846
    cs_fix[cs_fix$name=="Parker, Mike" & cs_fix$icpsr==95617,"icpsr"] <- 15617
    cs_fix[cs_fix$name=="Thornton, Raymond H., Jr." & cs_fix$icpsr==14058,"icpsr"] <- 29102
    cs_fix[cs_fix$name=="Deal, Nathan" & cs_fix$icpsr==99342,"icpsr"] <- 29342
    cs_fix[cs_fix$name=="Riggs, Frank" & cs_fix$icpsr==29103,"icpsr"] <- 29503
    
    cs_fix[is.element(cs_fix$icpsr,c("99767","89767","29767")) & cs_fix$name=="Goode, Vigil H., Jr.","name"] <- "Goode, Virgil H., Jr."
    cs_fix[cs_fix$icpsr=="15063" & cs_fix$name=="Smith, Robert F.","name"] <- "Smith, Robert F. (Bob)"
    cs_fix[cs_fix$icpsr=="15613" & cs_fix$name=="McDermott, James A." & cs_fix$cong==113,"name"] <- "McDermott, James"
    cs_fix[cs_fix$icpsr=="20535" & cs_fix$name=="McMorris, Cathy" & cs_fix$cong==111,"name"] <- "McMorris Rogers, Cathy"
    cs_fix[cs_fix$icpsr=="20535" & cs_fix$name=="McMorris, Cathy" & is.element(cs_fix$cong,c(110,112,113)),"name"] <- "McMorris Rodgers, Cathy"
    cs_fix[cs_fix$icpsr=="20917","name"] <- "Cao, Anh â€œJosephâ€\u009d"
    cs_fix[cs_fix$icpsr=="20932","name"] <- "Lujan, Ben Ray"
    cs_fix[cs_fix$name=="Lummis, Cynthia M." & cs_fix$cong==113,"name"] <- "Lummis, Cynthia"
    cs_fix[cs_fix$name=="Garamendi, John","name"] <- "Garamendi, John J."
    cs_fix[cs_fix$name=="Hochul, Kathy C.","name"] <- "Hochul, Kathleen C."
    cs_fix[cs_fix$name=="Desantis, Ron","name"] <- "DeSantis, Ron"
    cs_fix[cs_fix$name=="Deutch, Theodore E. (Ted)","name"] <- "Deutch, Theodore E."
    cs_fix[cs_fix$name=="Jeffries, Hakeem S.","name"] <- "Jeffries, Hakeem"
    cs_fix[cs_fix$name=="Cartwright, Matthew A.","name"] <- "Cartwright, Matthew"
    cs_fix[cs_fix$name=="Bono, Mary" & cs_fix$cong==112,"name"] <- "Bono Mack, Mary"
    cs_fix[cs_fix$name=="Biggert, Judy","name"] <- "Biggert, Judy."
    cs_fix[cs_fix$name=="Faleomavaega, Eni F.H.","name"] <- "Faleomavaega, Eni F. H."
    cs_fix[cs_fix$icpsr=="70801","name"] <- "FortuÃ±o, Luis G."
    
  # this process creates a few duplicates -- drop those
    
    cs_fix <- as.data.frame(cs_fix %>% distinct())
    
  # extract the relevant chunk of the committees file  
    
    com103 <- committees[committees$cong>=103,]
  
  # merge the new info into the committee file
  
    # aj_state_comm <- anti_join(com103,cs_fix)
    # aj_state_info <- anti_join(cs_fix,com103)
    # 
    # aji <- inner_join(aj_state_comm,aj_state_info,by=c("icpsr","cong"))
    # ajn <- inner_join(aj_state_comm,aj_state_info,by=c("name","cong"))
  
      # these anti-joins are to check how our merging is; the only ones
      # that are left un-merged already have states
    
    com103 <- left_join(com103,cs_fix) # we obviously don't merge on state or district since
                                       # the whole point is that they're often missing!
  
  
  # where we had been missing state and district info, add it in from this new data
  
  com103[is.na(com103$st_icpsr),"st_icpsr"] <- com103[is.na(com103$st_icpsr),"state_ic"]
  com103[is.na(com103$district),"district"] <- com103[is.na(com103$district),"district_fixer"]
  
  com103$district_fixer <- NULL; com103$state_ic <- NULL   # drop the unneeded columns
  
  # two folks are still missing state and district info
  
  com103[com103$name=="Tauzin, W. J. (Billy)" & com103$cong==104,"st_icpsr"] <- 45
  com103[com103$name=="Tauzin, W. J. (Billy)" & com103$cong==104,"district"] <- 3
  
  com103[com103$name=="Deal, Nathan" & com103$cong==104,"st_icpsr"] <- 44
  com103[com103$name=="Deal, Nathan" & com103$cong==104,"district"] <- 9
  
 # re-combine
  
  committees <- rbind(committees[committees$cong<103,],com103)
  
  committees$icpsr <- as.character(committees$icpsr)

# now we're going to merge in a state code crosswalk to put in postal codes
# this just simplifies things and lets us move on from the silly icpsr state codes

  cw <- as.data.frame(read_excel("./raw_data/StateFIPSicsprAB.xls"))
  cw <- cw[,c("STICPSR","AB")]
  colnames(cw) <- c("st_icpsr","state")

# fix a few -- for some reason hawaii and alaska (and PR and other territories) have some wrong codes
# in the committee data

  committees[committees$cong<=102 & committees$st_icpsr==81 & !is.na(committees$st_icpsr),"st_icpsr"] <- 91
  committees[committees$cong<=102 & committees$st_icpsr==82 & !is.na(committees$st_icpsr),"st_icpsr"] <- 83
  
  committees[committees$st_icpsr==75 & !is.na(committees$st_icpsr),"st_icpsr"] <- 82
  committees[committees$st_icpsr==74 & !is.na(committees$st_icpsr),"st_icpsr"] <- 81

# and we want to drop some folks from non-states

  committees <- committees[!is.element(committees$st_icpsr,
                                       c(83,  # puerto rico
                                         84,  # american samoa
                                         91,  # guam
                                         92,  # apparently also puerto rico 
                                         93,  # us virgin islands
                                         94,  # american samoa (again)
                                         95,  # northern mariana islands
                                         55   # DC
                                       )),]

# these folks just have wrong state codes

  committees[committees$st_icpsr==27,"st_icpsr"] <- 13
  committees[committees$st_icpsr==8,"st_icpsr"] <- 24

  committees <- left_join(committees,cw)

# load in poole-icpsr crosswalk from congressional bills project
# this is only for the 93rd to 105th congresses but gives us a nice
# principled way to fix some icpsr codes
# the issue is the the CVP data pretty clearly uses the poole-corrected ones,
# but CS's data seems to use the classic ones
# unfortunately some of the committee data's are just off, too (often by one
# or two) so this doesn't solve the problem fully

  cbp <- as.data.frame(read_excel("./raw_data/ICPSR crosswalk.xls"))
  
  cbp$lname <- gsub(" ","",fixed=T,gsub("[[:punct:]]","",tolower(trimws(unlist(lapply(str_split(cbp$NameFull,","),function(x) x[[1]]))))))
    # last name variable for the bills project data
  
  colnames(cbp) <- tolower(colnames(cbp))

  committees$lname <- gsub(" ","",fixed=T,gsub("[[:punct:]]","",tolower(trimws(unlist(lapply(str_split(committees$name,","),function(x) x[[1]]))))))
    # last name variable for the committees data
  
  com93105 <- committees[committees$cong>=93 & committees$cong<=105,]
    # limit the committee data to the period that can actually be helped by the congressional bills data
  
  com93105 <- left_join(com93105,cbp) # merge together by congress, icpsr number (original), and last name
    # this is a merge that's clearly not going to be perfect. but there shouldn't be any/many false-positives;
    # if anything it should miss merges that should happen. because we ultimately tie up all the loose ends below
    # this isn't a huge deal -- we just want whatever help this file can give us.
  
  com93105[com93105$icpsr!=com93105$poole & !is.na(com93105$poole),"icpsr"] <- com93105[com93105$icpsr!=com93105$poole & !is.na(com93105$poole),"poole"]
    # now if the committee icpsr number doesn't equal the poole value, set the icpsr to the poole value
  
  com93105 <- com93105[com93105$name!="Laughlin, Greg H." | (com93105$icpsr==15611 & com93105$party==100 & com93105$cong<=103) | (com93105$icpsr==95611 & com93105$party==200) | com93105$cong<103,]
  com93105 <- com93105[com93105$name!="Tauzin, W. J. (Billy)" | (com93105$icpsr==14679 & com93105$party==100 & com93105$cong<104) | (com93105$icpsr==94679 & com93105$party==200) | com93105$cong<103,]
  com93105 <- com93105[com93105$name!="Ireland, Andrew P." | (com93105$cong<=98 & com93105$icpsr==94428) | (com93105$cong>98 & com93105$icpsr==14428),]
    # these folks are all in the crosswalk twice for one congress, because of party-switching. So here we just
    # make sure we retain the one row that actually will let us merge to the CVP data.
  
  # now bind it back together
  
  committees <- rbind(committees[committees$cong<93 | committees$cong>105,],com93105[,is.element(colnames(com93105),colnames(committees))])

# now we're going to do some manual icpsr code fixes
# these issues were discovered based on non-matches when we merge the comm data and cvp data together
# the primary issue seems to be that the cvp data uses corrected icpsr scores while the committee data
# uses old ones. 

  # first, there are a few folks with two icpsr codes in a given congress in the original data--fix them
  
    committees[committees$name=="Boulter, Beau" & committees$cong==100,][1,"h_budget"] <- 1
    committees[committees$name=="Boulter, Beau" & committees$cong==100,] <- committees[committees$name=="Boulter, Beau" & committees$cong==100,][1,]
    
    committees[committees$name=="Combest, Larry" & committees$cong==99,][1,"h_agriculture"] <- 1
    committees[committees$name=="Combest, Larry" & committees$cong==99,] <- committees[committees$name=="Combest, Larry" & committees$cong==99,][1,]
    
    committees[committees$name=="Ros-Lehtinen, Ileana" & committees$cong==113,][1,"h_foreign_affairs"] <- 1
    committees[committees$name=="Ros-Lehtinen, Ileana" & committees$cong==113,] <- committees[committees$name=="Ros-Lehtinen, Ileana" & committees$cong==113,][1,]
    
    committees[committees$name=="Deutch, Theodore E." & committees$cong==113,][2,"h_conduct"] <- 1
    committees[committees$name=="Deutch, Theodore E." & committees$cong==113,] <- committees[committees$name=="Deutch, Theodore E." & committees$cong==113,][2,]
    
    committees[committees$name=="Hayes, James A." & committees$cong==104,][1,"h_ways_means"] <- 1
    committees[committees$name=="Hayes, James A." & committees$cong==104,] <- committees[committees$name=="Hayes, James A." & committees$cong==104,][1,]
    
    committees <- committees[!duplicated(committees),] # this just drops the extra observation for these folks
  
  # manual fixes to icpsr scores; these make it so that the committee data matches the
  # cvp data; they've also been confirmed to match the corrected poole icpsr codes
    
    committees[committees$name=="Laughlin, Greg H." & committees$cong<=103,"icpsr"] <- 15611
    committees[committees$name=="Abercrombie, Neil","icpsr"] <- 15245
    committees[committees$name=="Ros-Lehtinen, Ileana","icpsr"] <- 15634
    committees[committees$name=="Deutch, Theodore E.","icpsr"] <- 20959
    committees[committees$name=="Staggers, Harley O. Jr.","icpsr"] <- 15065
    committees[committees$name=="Lipinski, William O." & committees$cong<=108,"icpsr"] <- 15036
    committees[committees$name=="Grotberg, John E." & committees$cong==99,"icpsr"] <- 15102
    committees[committees$name=="Jarman, John" & committees$cong==94,"icpsr"] <- 94891
    committees[committees$name=="Riegle, Donald W. Jr." & committees$cong<=93,"icpsr"] <- 91043
    committees[committees$name=="Saiki, Patricia F.","icpsr"] <- 15441
    committees[committees$name=="Grant, Bill" & committees$cong==100,"icpsr"] <- 95415
    committees[committees$name=="Grant, Bill" & committees$cong==101,"icpsr"] <- 15415
    committees[committees$name=="Rhodes, John J. III" & (is.element(committees$cong,c(100,101,102))),"icpsr"] <- 15440
    committees[committees$name=="Payne, Donald M.","icpsr"] <- 15619
    committees[committees$name=="Robinson, Tommy F." & committees$cong<101,"icpsr"] <- 15122
    committees[committees$name=="Robinson, Tommy F." & committees$cong==101,"icpsr"] <- 95122
    committees[committees$name=="Luken, Charles A." & committees$cong==102,"icpsr"] <- 15823
    committees[committees$name=="Strickland, Ted","icpsr"] <- 29747
    committees[committees$name=="Thornton, Raymond H., Jr.","icpsr"] <- 14058
    committees[committees$name=="Riggs, Frank","icpsr"] <- 29103
    committees <- committees[committees$name!="Deal, Nathan" | committees$cong!=104 | committees$icpsr==99342,]
    committees[committees$name=="Deal, Nathan" & committees$cong==105,"icpsr"] <- 99342
    committees <- committees[committees$name!="Tauzin, W. J. (Billy)" | committees$cong!=104 | committees$icpsr==94679,]
    committees <- committees[committees$name!="Parker, Mike" | committees$cong!=104 | committees$icpsr==95617,]
    committees[committees$name=="Parker, Mike" & committees$cong>=104,"icpsr"] <- 95617
    committees[committees$name=="Parker, Mike" & committees$cong<104,"icpsr"] <- 15617
    committees[committees$name=="Watson, Albert W." & committees$cong<=89,"icpsr"] <- 90634
    committees[committees$name=="Bevill, Tom","icpsr"] <- 11000
    committees[committees$name=="Ackerman, Gary L.","icpsr"] <- 15000
    committees[committees$name=="Andrews, Michael A.","icpsr"] <- 15001
    committees[committees$name=="Bartlett, Steve","icpsr"] <- 15002
    committees[committees$name=="Bateman, Herbert H.","icpsr"] <- 15003
    committees[committees$name=="Bates, Jim","icpsr"] <- 15004
    committees[committees$name=="Berman, Howard L.","icpsr"] <- 15005
    committees[committees$name=="Bilirakis, Michael","icpsr"] <- 15006
    committees[committees$name=="Boehlert, Sherwood L.","icpsr"] <- 15007
    committees[committees$name=="Borski, Robert A.","icpsr"] <- 15008
    committees[committees$name=="Bosco, Douglas H.","icpsr"] <- 15009
    committees[committees$name=="Boucher, Frederick C.","icpsr"] <- 15010
    committees[committees$name=="Boxer, Barbara","icpsr"] <- 15011
    committees[committees$name=="Britt, Charles Robin","icpsr"] <- 15012
    committees[committees$name=="Bryant, John","icpsr"] <- 15013
    committees[committees$name=="Burton, Dan","icpsr"] <- 15014
    committees[committees$name=="Carper, Thomas R.","icpsr"] <- 15015
    committees[committees$name=="Chandler, Rodney","icpsr"] <- 15016
    committees[committees$name=="Clarke, James McClure","icpsr"] <- 15017
    committees[committees$name=="Coleman, Ronald D.","icpsr"] <- 15018
    committees[committees$name=="Cooper, Jim","icpsr"] <- 15019
    committees[committees$name=="DeWine, Michael","icpsr"] <- 15020
    committees[committees$name=="Durbin, Richard J.","icpsr"] <- 15021
    committees[committees$name=="Erdreich, Ben","icpsr"] <- 15022
    committees[committees$name=="Evans, Lane","icpsr"] <- 15023
    committees[committees$name=="Feighan, Edward F.","icpsr"] <- 15024
    committees[committees$name=="Franklin, Webb","icpsr"] <- 15025
    committees[committees$name=="Gekas, George W.","icpsr"] <- 15026
    committees[committees$name=="Harrison, Frank","icpsr"] <- 15027
    committees[committees$name=="Johnson, Nancy L.","icpsr"] <- 15028
    committees[committees$name=="Kaptur, Marcy","icpsr"] <- 15029
    committees[committees$name=="Kasich, John R.","icpsr"] <- 15030
    committees[committees$name=="Kolter, Joseph P.","icpsr"] <- 15031
    committees[committees$name=="Lehman, Richard H.","icpsr"] <- 15032
    committees[committees$name=="Levin, Sander M.","icpsr"] <- 15033
    committees[committees$name=="Levine, Mel","icpsr"] <- 15034
    committees[committees$name=="Lewis, Tom","icpsr"] <- 15035
    committees[committees$name=="MacKay, Kenneth H.","icpsr"] <- 15038
    committees[committees$name=="McCain, John","icpsr"] <- 15039
    committees[committees$name=="McCandless, Alfred A.","icpsr"] <- 15040
    committees[committees$name=="McCloskey, Francis X.","icpsr"] <- 15041
    committees[committees$name=="McKernan, John R. Jr.","icpsr"] <- 15042
    committees[committees$name=="McNulty, James F. Jr.","icpsr"] <- 15043
    committees[committees$name=="Schaefer, Daniel L.","icpsr"] <- 15058
    committees[committees$name=="Sikorski, Gerry","icpsr"] <- 15059
    committees[committees$name=="Sisisky, Norman","icpsr"] <- 15060
    committees[committees$name=="Slattery, Jim","icpsr"] <- 15061
    committees[committees$name=="Smith, Robert F.","icpsr"] <- 15063
    committees[committees$name=="Spratt, John M. Jr.","icpsr"] <- 15064
    committees[committees$name=="Sundquist, Don","icpsr"] <- 15066
    committees[committees$name=="Tallon, Robin","icpsr"] <- 15068
    committees[committees$name=="Thomas, Robert Lindsay","icpsr"] <- 15069
    committees[committees$name=="Torres, Esteban Edward","icpsr"] <- 15070
    committees[committees$name=="Torricelli, Robert G.","icpsr"] <- 15071
    committees[committees$name=="Towns, Edolphus","icpsr"] <- 15072
    committees[committees$name=="Valentine, I.T. Jr. (Tim)","icpsr"] <- 15073
    committees[committees$name=="Vandergriff, Tom","icpsr"] <- 15074
    committees[committees$name=="Vucanovich, Barbara F.","icpsr"] <- 15075
    committees[committees$name=="Wheat, Alan","icpsr"] <- 15076
    committees[committees$name=="Wise, Robert E. Jr.","icpsr"] <- 15077
    committees[committees$name=="Zschau, Ed","icpsr"] <- 15078
    committees[committees$name=="Hayes, Charles A.","icpsr"] <- 15079
    committees[committees$name=="Darden, George W. (Buddy)","icpsr"] <- 15081
    committees[committees$name=="Kleczka, Gerald D.","icpsr"] <- 15082
    committees[committees$name=="Mollohan, Alan B.","icpsr"] <- 15083
    committees[committees$name=="Atkins, Chester G.","icpsr"] <- 15084
    committees[committees$name=="Barton, Joe L.","icpsr"] <- 15085
    committees[committees$name=="Bentley, Helen Delich","icpsr"] <- 15086
    committees[committees$name=="Boulter, Beau","icpsr"] <- 15087
    committees[committees$name=="Bruce, Terry L.","icpsr"] <- 15088
    committees[committees$name=="Bustamante, Albert G.","icpsr"] <- 15089
    committees[committees$name=="Callahan, H. L. (Sonny)","icpsr"] <- 15090
    committees[committees$name=="Cobey, William W. Jr.","icpsr"] <- 15091
    committees[committees$name=="Coble, Howard","icpsr"] <- 15092
    committees[committees$name=="Combest, Larry","icpsr"] <- 15093
    committees[committees$name=="DeLay, Thomas D.","icpsr"] <- 15094
    committees[committees$name=="DioGuardi, Joseph J.","icpsr"] <- 15095
    committees[committees$name=="Eckert, Fred J.","icpsr"] <- 15097
    committees[committees$name=="Fawell, Harris W.","icpsr"] <- 15098
    committees[committees$name=="Gallo, Dean A.","icpsr"] <- 15099
    committees[committees$name=="Miller, John R.","icpsr"] <- 15110
    committees[committees$name=="Armey, Richard","icpsr"] <- 15125
    committees[committees$name=="Hendon, William M.","icpsr"] <- 14832
    committees[committees$name=="Long, Cathy","icpsr"] <- 15128
    committees[committees$name=="Chapman, Jim","icpsr"] <- 15129
    committees[committees$name=="Gordon, Bart","icpsr"] <- 15100
    committees[committees$name=="Patterson, Elizabeth J.","icpsr"] <- 15171
    committees[committees$name=="Waldon, Alton R.","icpsr"] <- 15244
    committees[committees$name=="Baker, Richard H.","icpsr"] <- 15401
    committees[committees$name=="Ballenger, Cass","icpsr"] <- 15402
    committees[committees$name=="Bilbray, James H.","icpsr"] <- 15403
    committees[committees$name=="Brennan, Joseph E.","icpsr"] <- 15404
    committees[committees$name=="Buechner, Jack","icpsr"] <- 15405
    committees[committees$name=="Bunning, Jim","icpsr"] <- 15406
    committees[committees$name=="Campbell, Ben Nighthorse","icpsr"] <- 15407
    committees[committees$name=="Cardin, Benjamin L.","icpsr"] <- 15408
    committees[committees$name=="Davis, Jack","icpsr"] <- 15409
    committees[committees$name=="DeFazio, Peter A.","icpsr"] <- 15410
    committees[committees$name=="Espy, Mike","icpsr"] <- 15411
    committees[committees$name=="Flake, Floyd H.","icpsr"] <- 15412
    committees[committees$name=="Gallegly, Elton","icpsr"] <- 15413
    committees[committees$name=="Grandy, Fred","icpsr"] <- 15414
    committees[committees$name=="Harris, Claude","icpsr"] <- 15416
    committees[committees$name=="Hastert, J. Dennis","icpsr"] <- 15417
    committees[committees$name=="Hayes, James A.","icpsr"] <- 15418
    committees[committees$name=="Hefley, Joel","icpsr"] <- 15419
    committees[committees$name=="Herger, Wally","icpsr"] <- 15420
    committees[committees$name=="Hochbrueckner, George J.","icpsr"] <- 15421
    committees[committees$name=="Holloway, Clyde C.","icpsr"] <- 15422
    committees[committees$name=="Houghton, Amory Jr.","icpsr"] <- 15423
    committees[committees$name=="Inhofe, James M.","icpsr"] <- 15424
    committees[committees$name=="Johnson, Tim","icpsr"] <- 15425
    committees[committees$name=="Jontz, James","icpsr"] <- 15426
    committees[committees$name=="Kennedy, Joseph P. II","icpsr"] <- 15427
    committees[committees$name=="Konnyu, Ernest L.","icpsr"] <- 15428
    committees[committees$name=="Kyl, Jon","icpsr"] <- 15429
    committees[committees$name=="Lancaster, H. Martin","icpsr"] <- 15430
    committees[committees$name=="Lewis, John","icpsr"] <- 15431
    committees[committees$name=="McMillen, C. Thomas","icpsr"] <- 15432
    committees[committees$name=="Mfume, Kweisi","icpsr"] <- 15433
    committees[committees$name=="Morella, Constance A.","icpsr"] <- 15434
    committees[committees$name=="Nagle, David R.","icpsr"] <- 15435
    committees[committees$name=="Pickett, Owen B.","icpsr"] <- 15437
    committees[committees$name=="Price, David E.","icpsr"] <- 15438
    committees[committees$name=="Ravenel, Arthur Jr.","icpsr"] <- 15439
    committees[committees$name=="Sawyer, Thomas C.","icpsr"] <- 15442
    committees[committees$name=="Skaggs, David E.","icpsr"] <- 15443
    committees[committees$name=="Slaughter, Louise M.","icpsr"] <- 15444
    committees[committees$name=="Smith, Lamar S.","icpsr"] <- 15445
    committees[committees$name=="Upton, Frederick S.","icpsr"] <- 15446
    committees[committees$name=="Weldon, Curt","icpsr"] <- 15447
    committees[committees$name=="Pelosi, Nancy","icpsr"] <- 15448
    committees[committees$name=="Shays, Christopher","icpsr"] <- 15449
    committees[committees$name=="Clement, Bob","icpsr"] <- 15450
    committees[committees$name=="McCrery, Jim","icpsr"] <- 15451
    committees[committees$name=="Payne, Lewis F. Jr.","icpsr"] <- 15452
    committees[committees$name=="Costello, Jerry F.","icpsr"] <- 15453
    committees[committees$name=="Pallone, Frank Jr.","icpsr"] <- 15454
    committees[committees$name=="Duncan, John (Jimmy) Jr.","icpsr"] <- 15455
    committees[committees$name=="Campbell, Tom","icpsr"] <- 15600
    committees[committees$name=="Cox, C. Christopher","icpsr"] <- 15601
    committees[committees$name=="Douglas, Charles","icpsr"] <- 15602
    committees[committees$name=="Engel, Eliot L.","icpsr"] <- 15603
    committees[committees$name=="Gillmor, Paul E.","icpsr"] <- 15604
    committees[committees$name=="Goss, Porter J.","icpsr"] <- 15605
    committees[committees$name=="Hancock, Melton D.","icpsr"] <- 15606
    committees[committees$name=="Hoagland, Peter","icpsr"] <- 15607
    committees[committees$name=="James, Craig T.","icpsr"] <- 15608
    committees[committees$name=="Johnston, Harry A.","icpsr"] <- 15609
    committees[committees$name=="Lowey, Nita M.","icpsr"] <- 15612
    committees[committees$name=="McDermott, James A.","icpsr"] <- 15613
    committees[committees$name=="McNulty, Michael R.","icpsr"] <- 15614
    committees[committees$name=="Neal, Richard E.","icpsr"] <- 15616
    committees[committees$name=="Paxon, L. William","icpsr"] <- 15618
    committees[committees$name=="Poshard, Glenn","icpsr"] <- 15620
    committees[committees$name=="Rohrabacher, Dana","icpsr"] <- 15621
    committees[committees$name=="Sangmeister, George E.","icpsr"] <- 15622
    committees[committees$name=="Sarpalius, Bill","icpsr"] <- 15623
    committees[committees$name=="Schiff, Steven H.","icpsr"] <- 15624
    committees[committees$name=="Smith, Larkin","icpsr"] <- 15625
    committees[committees$name=="Smith, Peter P.","icpsr"] <- 15626
    committees[committees$name=="Stearns, Cliff","icpsr"] <- 15627
    committees[committees$name=="Tanner, John","icpsr"] <- 15628
    committees[committees$name=="Tanner, John S.","icpsr"] <- 15628
    committees[committees$name=="Unsoeld, Jolene","icpsr"] <- 15629
    committees[committees$name=="Walsh, James T.","icpsr"] <- 15630
    committees[committees$name=="Long, Jill L.","icpsr"] <- 15631
    committees[committees$name=="Browder, Glen","icpsr"] <- 15632
    committees[committees$name=="Thomas, Craig","icpsr"] <- 15633
    committees[committees$name=="Condit, Gary","icpsr"] <- 15635
    committees[committees$name=="Geren, Pete","icpsr"] <- 15636
    committees[committees$name=="Taylor, Gene (MS)","icpsr"] <- 15637
    committees[committees$name=="Cramer, Bud","icpsr"] <- 29100
    committees[committees$name=="Molinari, Susan","icpsr"] <- 15639
    committees[committees$name=="Pastor, Ed","icpsr"] <- 29101
    committees[committees$name=="Doolittle, John T.","icpsr"] <- 29104
    committees[committees$name=="Waters, Maxine","icpsr"] <- 29106
    committees[committees$name=="Dooley, Calvin","icpsr"] <- 29105
    committees[committees$name=="Cunningham, Randy","icpsr"] <- 29107
    committees[committees$name=="Allard, Wayne","icpsr"] <- 29108
    committees[committees$name=="DeLauro, Rosa","icpsr"] <- 29109
    committees[committees$name=="Franks, Gary","icpsr"] <- 29110
    committees[committees$name=="Peterson, Pete","icpsr"] <- 29111
    committees[committees$name=="Bacchus, Jim","icpsr"] <- 29112
    committees[committees$name=="LaRocco, Larry","icpsr"] <- 29114
    committees[committees$name=="Ewing, Thomas W.","icpsr"] <- 29115
    committees[committees$name=="Cox, John W. Jr.","icpsr"] <- 29116
    committees[committees$name=="Roemer, Timothy J.","icpsr"] <- 29117
    committees[committees$name=="Nussle, Jim","icpsr"] <- 29118
    committees[committees$name=="Nichols, Dick","icpsr"] <- 29119
    committees[committees$name=="Jefferson, William J.","icpsr"] <- 29120
    committees[committees$name=="Andrews, Thomas H.","icpsr"] <- 29121
    committees[committees$name=="Gilchrest, Wayne T.","icpsr"] <- 29122
    committees[committees$name=="Olver, John W.","icpsr"] <- 29123
    committees[committees$name=="Camp, Dave","icpsr"] <- 29124
    committees[committees$name=="Collins, Barbara-Rose","icpsr"] <- 29125
    committees[committees$name=="Ramstad, Jim","icpsr"] <- 29126
    committees[committees$name=="Peterson, Collin C.","icpsr"] <- 29127
    committees[committees$name=="Horn, Joan Kelly","icpsr"] <- 29128
    committees[committees$name=="Barrett, Bill","icpsr"] <- 29129
    committees[committees$name=="Zeliff, William","icpsr"] <- 29130
    committees[committees$name=="Swett, Dick","icpsr"] <- 29131
    committees[committees$name=="Andrews, Robert E.","icpsr"] <- 29132
    committees[committees$name=="Zimmer, Richard","icpsr"] <- 29133
    committees[committees$name=="Serrano, Jose E.","icpsr"] <- 29134
    committees[committees$name=="Taylor, Charles H.","icpsr"] <- 29135
    committees[committees$name=="Hobson, David L.","icpsr"] <- 29136
    committees[committees$name=="Boehner, John A.","icpsr"] <- 29137
    committees[committees$name=="Brewster, Bill","icpsr"] <- 29138
    committees[committees$name=="Kopetski, Mike","icpsr"] <- 29139
    committees[committees$name=="Blackwell, Lucien","icpsr"] <- 29140
    committees[committees$name=="Santorum, Rick","icpsr"] <- 29141
    committees[committees$name=="Reed, John F.","icpsr"] <- 29142
    committees[committees$name=="Johnson, Sam","icpsr"] <- 29143
    committees[committees$name=="Edwards, Chet","icpsr"] <- 29144
    committees[committees$name=="Washington, Craig","icpsr"] <- 29145
    committees[committees$name=="Orton, Bill","icpsr"] <- 29146
    committees[committees$name=="Sanders, Bernard","icpsr"] <- 29147
    committees[committees$name=="Allen, George F.","icpsr"] <- 29148
    committees[committees$name=="Moran, James P. Jr.","icpsr"] <- 29149
    committees[committees$name=="Klug, Scott L.","icpsr"] <- 29150
    committees[committees$name=="Peyser, Peter A." & committees$cong==92,"icpsr"] <- 93033
    committees[committees$name=="Jones, Ben","icpsr"] <- 95120
    committees[committees$name=="Burton, Sala","icpsr"] <- 15080
  
  # some folks also have incorrect district numbers or states in the committees data
  # fix those here too
    
    committees[committees$name=="Strickland, Ted","district"] <- 6
    committees[committees$name=="Riggs, Frank","district"] <- 1
    committees[committees$name=="Thornton, Raymond H., Jr." & committees$cong>=102,"district"] <- 2
    committees[committees$name=="Parker, Mike" & committees$cong==105,"district"] <- 4
    committees[committees$name=="Tauzin, W. J. (Billy)" & committees$cong==105,"district"] <- 3
    committees[committees$name=="Deal, Nathan" & committees$cong==105,"district"] <- 9
    committees[committees$name=="Westmoreland, Lynn A." & is.element(committees$cong,c(110,111)),"district"] <- 3
    committees[committees$name=="Marshall, Jim" & is.element(committees$cong,c(110,111)),"district"] <- 8
    committees[committees$name=="Linder, John" & committees$cong==105,"district"] <- 11
    committees[committees$name=="McKinney, Cynthia A." & committees$cong==105,"district"] <- 4
    committees[committees$name=="Deal, Nathan" & is.element(committees$cong,c(110,111)),"district"] <- 9
    committees[committees$name=="Norwood, Charles W., Jr." & committees$cong==110,"district"] <- 10
    committees[committees$name=="Gallagher, Cornelius E." & committees$cong==90,"district"] <- 13
    committees[committees$name=="Sisk, B. F." & is.element(committees$cong,c(94,95)),"district"] <- 15
    committees[committees$name=="Hoyer, Steny H." & committees$cong==97,"district"] <- 5
    committees[committees$name=="Burton, Phillip" & committees$cong==98,"district"] <- 5
    committees[committees$name=="Weiss, Theodore S." & committees$cong==98,"district"] <- 17
    committees[committees$name=="Durbin, Richard J." & is.element(committees$cong,c(100:102)),"district"] <- 20
    committees[committees$name=="Stallings, Richard H." & is.element(committees$cong,c(100:102)),"district"] <- 2
    committees[committees$name=="LaTourette, Steven C." & is.element(committees$cong,c(108:110)),"district"] <- 14
    committees[committees$name=="Bilbray, Brian P." & committees$cong==109,"district"] <- 50
    committees[committees$name=="Thomas, William M." & committees$cong==109,"district"] <- 22
    committees[committees$name=="Burton, Sala" & committees$cong==98,"district"] <- 5
    
    committees[committees$name=="Long, Jill L.","state"] <- "IN"
    committees[committees$name=="Long, Jill L.","st_icpsr"] <- 22
    
    committees[committees$name=="Payne, Lewis F. Jr.","state"] <- "VA"
    committees[committees$name=="Payne, Lewis F. Jr.","st_icpsr"] <- 40

# now we create long-form committee data, rather than the wide-form that it's currently in
# this means each observation, instead of being an MC-congress, will be an MC-congress-committee,
# with the main variable being an indicator for whether they served on that committee or not

# move to long-form

  committees <- committees %>% arrange(icpsr,cong)
  comm_long  <- committees %>% gather(committee,on_committee,h_agriculture:h_ways_means)

# trim committee names

  comm_long$committee <- trimws(gsub("h_","",fixed=T,comm_long$committee))

# calculate the total number of folks on each committee by congress and add to the dataset

  committee_aggregates <- as.data.frame(comm_long %>% group_by(cong,committee) %>% summarise(n_comm_members = sum(on_committee)))

  comm_long <- merge(comm_long,committee_aggregates,by=c("cong","committee"),all.x=T)

# create lags and leads for parallel trends test

  comm_long$comm_icpsr <- paste(comm_long$committee,comm_long$icpsr)
    # the relevant unit for this is the member-committee, so we create that group variable first
  
  # for each one we make sure it's nicely ordered first, then create the lag or lead accordingly

  comm_long <- comm_long %>% arrange(comm_icpsr,cong)
  comm_long <- DataCombine::slide(data=comm_long,Var="on_committee",TimeVar="cong",GroupVar="comm_icpsr",slideBy = -1,NewVar="on_committee_lag",keepInvalid = T)
  comm_long <- comm_long %>% arrange(comm_icpsr,cong)
  comm_long <- DataCombine::slide(data=comm_long,Var="on_committee",TimeVar="cong",GroupVar="comm_icpsr",slideBy =  1,NewVar="on_committee_lead",keepInvalid = T)
  comm_long <- comm_long %>% arrange(comm_icpsr,cong)
  comm_long <- DataCombine::slide(data=comm_long,Var="on_committee",TimeVar="cong",GroupVar="comm_icpsr",slideBy = -2,NewVar="on_committee_lag2",keepInvalid = T)
  comm_long <- comm_long %>% arrange(comm_icpsr,cong)
  comm_long <- DataCombine::slide(data=comm_long,Var="on_committee",TimeVar="cong",GroupVar="comm_icpsr",slideBy =  2,NewVar="on_committee_lead2",keepInvalid = T)

# finally, trim the committee data down to the committees we'll actually use
# we'd only kept the 81st, 82nd, 112th, and 113th around for lag-lead purposes
  
  comm_long <- comm_long[comm_long$cong>=83 & comm_long$cong<=111,]

###################################################################################################
# load, clean, and process conservative vote probabilities data ###################################
###################################################################################################

# load in unadjusted conservative vote probabilities data
# (from https://www.dropbox.com/s/068voyg8gxk5wsw/CVP_by_issue_83_111.csv?dl=0)      

  cvp <- read.csv("./raw_data/CVP_by_issue_83_111.csv")

# move to long-form

  cvp_long <- cvp %>% gather(issue,cvp,cvp_appropriations:cvp_labor)

# trim issue name

  cvp_long$issue <- trimws(gsub("cvp_","",fixed=T,cvp_long$issue))

# rename id column icpsr

  cvp_long <- plyr::rename(cvp_long,replace=c("id"="icpsr"))
  cvp_long$icpsr <- as.character(cvp_long$icpsr)

# now load in adjusted conservative vote probabilities data
# these were put together by jon and are separate files by issue

  ada_list <- list() # list to store the loaded files
  ada_files <- paste("./raw_data/",grep("a.b.x",list.files(path="./raw_data",pattern="_base100"),invert=T,value=T),sep="")
    # list of files
  
  # now loop over the files, load them in, make outliers NA, and store the files

  for(j in 1:length(ada_files)){
    
    file <- read.csv(ada_files[j])
    
    # add issue topic from file name
    
    file$issue <- gsub("_base100.csv","",fixed=T,gsub("./raw_data/Real_","",fixed=T,ada_files[j]))
    
    # fix a few of these that are really outlandish
    
    file[abs(file$Adj.Score)>4,"Adj.Score"] <- NA
    
    # store file
    
    ada_list[[j]] <- file
    
  }

# combine the files and adjust variable names 

  ada_dat <- do.call(rbind,ada_list)
  colnames(ada_dat) <- tolower(colnames(ada_dat))
  ada_dat <- plyr::rename(ada_dat,replace=c("year"="cong")); ada_dat$chamber <- NULL

# merge with the non-adjusted scores

  cvp_long <- merge(cvp_long,ada_dat,by=c("icpsr","cong","issue"),all.x=T,all.y=T)

# fix a few icpsr codes

  cvp_long[trimws(cvp_long$name)=="HENDON  B" & cvp_long$cong==99 & cvp_long$state=="NC","icpsr"] <- 14832
  
# drop a few columns we don't need or use
  
  cvp_long$nominalscore <- NULL # just a duplicate of the unadjusted cvp scores
  cvp_long$mean.adj.score <- NULL # kind of defeats the point of adjusting the scores in the first place!

###################################################################################################
# merge committee and cvp data ####################################################################
###################################################################################################    

# add a column called "matcher" to both the committee and cvp data
# for the committee data, it's just the committee
# for the cvp data, it's the committee that an issue area gets mapped to
# we're going to merge the committee data to the cvp data, so some committees will get dropped
# but only issue areas that we intentionally don't match to a committee will get lost

  comm_long$matcher <- comm_long$committee  

  cvp_long$matcher <- NA
  cvp_long[cvp_long$issue=="economy","matcher"] <- "ways_means"
  cvp_long[cvp_long$issue=="agriculture","matcher"] <- "agriculture"
  cvp_long[cvp_long$issue=="labor","matcher"] <- "educ_labor"
  cvp_long[cvp_long$issue=="education","matcher"] <- "educ_labor"
  cvp_long[cvp_long$issue=="energy","matcher"] <- "energy_commerce"
  cvp_long[cvp_long$issue=="welfare","matcher"] <- "ways_means"
  cvp_long[cvp_long$issue=="housing","matcher"] <- "banking"
  cvp_long[cvp_long$issue=="defense","matcher"] <- "armed_services"
  cvp_long[cvp_long$issue=="trade","matcher"] <- "ways_means"
  cvp_long[cvp_long$issue=="foreignpolicy","matcher"] <- "foreign_affairs"
  cvp_long[cvp_long$issue=="veterans","matcher"] <- "vet_affairs"
  cvp_long[cvp_long$issue=="taxes","matcher"] <- "ways_means"
  cvp_long[cvp_long$issue=="appropriations","matcher"] <- "appropriations"
  cvp_long[cvp_long$issue=="finance","matcher"] <- "banking"

# senior issues and environmental issues are the two that we don't have committee matches for

  cvp_long <- cvp_long[!is.na(cvp_long$matcher),] # drops the senior and environmental policy areas

# remove committee stuff that we don't have a relevant match for
# this drops the following committees: budget, conduct, dc, govt_operations, house administration,
# interior, internal_security, judiciary, merchant marine, natural resources, post office,
# public works, rules, science, and small business 

  comm_long <- comm_long[is.element(comm_long$matcher,unique(cvp_long$matcher)),]

# trim down to the relevant columns in preparation for merging

  cvp_long <- cvp_long[,c("matcher","icpsr","cong","issue","state","dist","cvp","adj.score","dem","rep","name")]
  cvp_long <- plyr::rename(cvp_long,replace=c("name"="name_cvp"))
  cvp_long[cvp_long$dist>55 | cvp_long$dist==0,"dist"] <- 0
  cvp_long$dist_match <- cvp_long$dist
  cvp_long$dist_match[cvp_long$dist_match==0] <- 1
    # note that we fix up the districts to allow for anything not numbered normally to be 0
    # but just to make sure we actually merge we make a district match variable that is 1 for anything
    # that's district 1 or that seems to be at-large; we do the same for the committee data in the next lines

  comm_long <- comm_long[,c("matcher","icpsr","cong","state","district","committee","on_committee","name","n_comm_members",
                            "on_committee_lead","on_committee_lag","on_committee_lead2","on_committee_lag2")]
  comm_long$dist_match <- comm_long$district; comm_long$district <- NULL
  comm_long[comm_long$dist_match>55,"dist_match"] <- 1

  # in order to maximize the number of merges while also ensuring that the merges are correct,
  # mike used anti_join to find the observations from the cvp data that were found not to have a 
  # match in the committees data (anti_cvp) and vice versa (anti_comm). merges were made based on 
  # the policy area, the icpsr number, the congress, the state, and the district (slightly amended 
  # to ensure that all at-large districts are coded the same). the primary issue is likely to be
  # that CS's committee data appears to primarily use "original" icpsr scores (often off by 1 or 2), 
  # while the cvp data uses the version updated and corrected by keith poole and howard rosenthal. 
  # this motivates the changes in lines XX through XX above.
  
  # anti_cvp <- dplyr::anti_join(cvp_long,comm_long,by=c("matcher","icpsr","cong","state","dist_match"))
  # anti_cvp <- anti_cvp %>% distinct(icpsr,cong,.keep_all = T) # this is going to drop all but one policy area
  # anti_cvp <- anti_cvp[,c("icpsr","cong","state","dist_match","dem","name")] # this drops that column since we don't need it
  # anti_cvp$name <- trimws(tolower(anti_cvp$name)) # give us a useable name
  # 
  # anti_comm <- dplyr::anti_join(comm_long,cvp_long,by=c("matcher","icpsr","cong","state","dist_match"))
  # anti_comm <- anti_comm %>% distinct(icpsr,cong,.keep_all = T) # this is going to drop all but one policy area
  # anti_comm <- anti_comm[,c("icpsr","cong","state","dist_match","name")] # this drops that column since we don't need it
  # anti_comm$name <- trimws(tolower(anti_comm$name))
  # anti_comm <- anti_comm[anti_comm$state!="DC",]
  # 
  # asd <- inner_join(anti_cvp,anti_comm,by=c("cong","state","dist_match"))
  # ais <- inner_join(anti_cvp,anti_comm,by=c("cong","state","icpsr"))
  # aid <- inner_join(anti_cvp,anti_comm,by=c("cong","dist_match","icpsr"))
  # ai <- inner_join(anti_cvp,anti_comm,by=c("cong","icpsr"))
  
  # I also went through the remaining state-congresses in anti_comm and checked for matching observatiosn
  # in the same states and years in anti_cvp

# create a last name variable for the committee data

  comm_long$lname <- tolower(unlist(lapply(str_split(comm_long$name,","),function(x) x[[1]])))

# finally, merge them together
# note that there are multiple matches due to multiple issues matching up to a committee
  
  merged <- dplyr::full_join(cvp_long,comm_long,by=c("matcher","icpsr","cong","state","dist_match"))

# check names

  # s <- merged[,c("icpsr","name_cvp","lname")]
  # s$name <- trimws(tolower(s$name_cvp))
  # s$name_full <- s$name
  # s$name <- tolower(unlist(lapply(str_split(s$name," "),function(x) x[[1]])))
  # s$name2 <- str_sub(s$name,1,2); s$lname2 <- str_sub(s$lname,1,2)
  # s <- s %>% distinct(name,lname,.keep_all=T)
  # s <- s[s$name2!=s$lname2,]

# now we drop any observation that is missing either the committee indicator
# or the cvp score; we can't do much with those observations
# because we did a full join above this drops a reasonable number of rows
# we use the unadjusted CVP score here because we use that data as the basis
# for merging in the adjusted scores so it's never missing when the adjusted 
# aren't; this will still have some cases of missing adjusted scores

  merged <- merged[!is.na(merged$cvp) & !is.na(merged$on_committee),]

# now we make some pretty names for issue areas

  merged$`Issue Area` <- paste(toupper(str_sub(merged$issue,1,1)),str_sub(merged$issue,2),sep="")
  merged[merged$`Issue Area`=="Foreignpolicy","Issue Area"] <- "Foreign Policy"

###################################################################################################
# merge in jacobson data on presidential vote shares at congressional district level ##############
###################################################################################################   

# load the jacobson data

  jac <- as.data.frame(read_dta("./raw_data/jacobson_1946-2014.dta"))  
  
  jac <- jac[,c("district","st_abbrev","dpres","year")]
    # limit the columns
  
  jac$cong <- (jac$year-1786)/2
    # create a congress variable
    # since it's election years, we want 1788 to line up with 1, etc
  
  jac <- plyr::rename(jac,replace=c("district"="dist","st_abbrev"="state"))
    # rename a few columns

# make a few tweaks

  jac[jac$dist>55,"dist"] <- 0 # make at-large districts 0
  
  jac[jac$state=="NM" & jac$cong<=90,"dist"] <- 0
  jac[jac$state=="ND" & jac$cong<=87,"dist"] <- 0
  jac[jac$state=="HI" & jac$cong<=91,"dist"] <- 0
    # re-code some cases with only one district as at-large to match
  
  jac[jac$state=="HI" & jac$cong==86.5,"cong"] <- 86
  jac[jac$state=="HI" & jac$cong==90,"dpres"] <- jac[jac$state=="HI" & jac$cong==89,"dpres"]
    # fix a few weirdnesses with hawaii, specifically

# drop duplicates--probably here if the at-large district was in the data originally, and we re-added it  

  jac <- jac %>% arrange(cong,year,state,dist,dpres)
  jac <- as.data.frame(jac %>% distinct(state,dist,cong,.keep_all = T))

# make one change in the left-hand data

  merged[merged$state=="HI" & merged$cong<=91,"dist"] <- 0  
    # hawaii had 2 seats but used at-large elections to choose both before this

# merge the jacobson data into the committee/voting data
  
  mc <- merge(merged,jac,by=c("cong","state","dist"),all.x=T)
  mc$year <- 1786+2*mc$cong

  # there are a handful of cases -- all at-large districts, I think
  # in states that probably didn't have that generally as the way
  # of doing things, that are missing. these will all get dropped
  # later, except for one which is used for the exile analysis;
  # we add that in that file. others are missing but because they
  # are missing in the jacobson file.
  
  # make the variable republican vote share
  
  mc$rpres <- 1-(mc$dpres/100)
  
###################################################################################################
# merge in district information for district id creation  #########################################
###################################################################################################

# now we're going to load in the metadata files for the lewis + friends
# shapefiles, which contain the year that particular district versions
# start and stop. we do this to create a district identifier that accounts
# for redistricting

  districts <- list()

  for(j in 83:111){

    # create a path for each congress

    path <- paste("./raw_data/districts",
                  gsub(" ","0",fixed=T,format(83:111,nbig=3)),
                  ".dbf",sep="")[j-82]

    # read in the path

    bit <- read.dbf(path)

    bit$cong <- j
      # add in a congress variable

    districts[[j-82]] <- bit
      # save each year in the list

  }

  districts <- as.data.frame(do.call(rbind,districts))
    # bind the different congresses together

  districts <- districts[,c("STATENAME","DISTRICT","STARTCONG","ENDCONG","cong")]
    # save the relevant columns

  colnames(districts) <- tolower(colnames(districts))
  districts <- arrange(districts,statename,district)
    # fix up the column names and asrrange nicely

  state_merger <- as.data.frame(cbind(state.name,state.abb))
  colnames(state_merger) <- c("statename","state")
  districts <- merge(districts,state_merger,by="statename",all.x=T)
  districts <- plyr::rename(districts,replace=c("district"="dist"))
    # add in state abbreviations and rename columns appropriately
  
  # now we need to fix up some district labels in the main data
  # in particular we need to get consistency on what at-large districts
  # are labeled.

    mc[mc$dist>55,"dist"] <- 0
    mc[is.element(mc$state,
                  c("AK","DE",
                    "VT","WY")),
       "dist"] <- 0
    mc[mc$state=="HI" & mc$cong<=87,"dist"] <- 0
    mc[mc$state=="MT" & mc$cong>=103,"dist"] <- 0
    mc[mc$state=="ND" & (mc$cong>=93 | mc$cong<=87),"dist"] <- 0
    mc[mc$state=="SD" & mc$cong>=98,"dist"] <- 0
    mc[mc$state=="NV" & mc$cong>=83 & mc$cong<=97,"dist"] <- 0
    
# merge the district ids into the data and create a district id variable

  mc <- merge(mc,districts,by=c("state","dist","cong"),all.x=T)
    
  mc$distid <- paste(mc$state,mc$dist,mc$startcong,mc$endcong,sep="_")
  
  # fix at-large districts
  
  mc[mc$dist==0,"distid"] <- paste(mc$state[mc$dist==0],mc$dist[mc$dist==0],sep="_")

###################################################################################################
# merge in committee staffing levels from the Congressional Research Service  #####################
###################################################################################################

# data is OCRed so kind of messily formatted, need to do some cleaning 
# it's kind of in chunks, with headers repeated at various points in the data
# so we chunk it up, put it in longform by chunk (with each chunk corresponding
# to a particular batch of years), 

# first load data
  
  crs <- read.csv("./raw_data/crs_tables.csv")

  crs1 <- crs[1:23,]
  crs1 <- crs1 %>% gather(year,n_staff,X2007:X2016)
  colnames(crs1)[1] <- "Committee"

  crs2 <- crs[24:50,]
  colnames(crs2) <- as.character(unlist(crs2[1,]))
  crs2 <- crs2[-1,]
  colnames(crs2)[2:ncol(crs2)] <- paste("X",colnames(crs2)[2:ncol(crs2)] ,sep="")
  crs2 <- crs2 %>% gather(year,n_staff,X1997:X2006)
    # after the first chunk we have to do a bit more to reassign column names
    # etc. etc.; including adding Xs to be consistent with the first one for
    # later consistency's sake (not the best way to do it but it works)

  crs25 <- crs[51:79,]  
  colnames(crs25) <- paste("X",as.character(unlist(crs25[1,])),sep="")
  colnames(crs25)[1] <- "Committee"
  crs25 <- crs25[-1,]
  crs25 <- crs25 %>% gather(year,n_staff,X1987:X1996)

  crs3 <- crs[80:81,]
  colnames(crs3) <- as.character(unlist(crs3[1,]))
  crs3 <- crs3[-1,]

  crs4 <- crs[82:nrow(crs),]
  colnames(crs4) <- as.character(unlist(crs4[1,]))
  crs4 <- crs4[-1,]
  crs3 <- rbind(crs3,crs4); crs4 <- NULL
  colnames(crs3)[2:ncol(crs3)] <- paste("X",colnames(crs3)[2:ncol(crs3)] ,sep="")
  crs3 <- crs3 %>% gather(year,n_staff,X1977:X1986)
    # chunks 3 and 4 are for the same set of years; agriculture was just 
    # hanging on at the end of a page or something

  crs <- rbind(crs1,crs2,crs25,crs3)
    # combine the chunks

# fix some committee names  

  crs$Committee <- tolower(gsub("\n"," ",fixed=T,crs$Committee))
  crs[crs$Committee=="armed services","Committee"] <- "armed_services"
  crs[crs$Committee=="financial services","Committee"] <- "banking"
  crs[crs$Committee=="education and labor","Committee"] <- "educ_labor"
  crs[crs$Committee=="energy and commerce","Committee"] <- "energy_commerce"
  crs[crs$Committee=="foreign affairs","Committee"] <- "foreign_affairs"
  crs[crs$Committee=="veterans????T affairs","Committee"] <- "vet_affairs"
  crs[crs$Committee=="ways and means","Committee"] <- "ways_means"
  crs[crs$Committee=="veterans????T affairs" ,"Committee"] <- "vet_affairs"
  crs[crs$Committee=="veterans’ affairs" ,"Committee"] <- "vet_affairs"
  
# and fix the year variable, plus make a congress variable  

  crs$year <- as.integer(gsub("X","",fixed=T,crs$year))
    # just get rid of the X -- easy
  
  crs_yearly <- crs
  
  crs[crs$year%%2==0,"year"] <- crs[crs$year%%2==0,"year"]-1
    # make even years on the previous odd year
  crs$cong <- (crs$year-1787)/2;  crs$year <- NULL
    # then convert to congresses
  colnames(crs) <- tolower(colnames(crs))
    # fix column names and get rid of the year variable

# make number of staff numeric, and then aggregate to the congress level (data is yearly)

  crs[crs$n_staff=="-","n_staff"] <- NA
  crs$n_staff <- as.numeric(as.character(crs$n_staff))
  
  crs <- crs %>% group_by(cong,committee) %>% summarise(n_staff=mean(n_staff))

# merge this information into the main dataset

  mc <- merge(mc,crs,by=c("committee","cong"),all.x=T) 
  
# create some of the measures and variables that we'll use
  
  mc$int <- mc$rpres*mc$on_committee
  mc$logstaff <- log(mc$n_staff)
  mc$staff_com <- mc$logstaff*mc$on_committee
  mc$staff_rpres <- mc$logstaff*mc$rpres
  mc$staff_per_member <- log(mc$n_staff/mc$n_comm_members)
  
###################################################################################################
# use nominate data to determine which party is in the majority ###################################
###################################################################################################

  nom <- read.csv("./raw_data/Hall_members.csv")
  
  nom <- nom[nom$congress>=83 & nom$congress<=111,]
    # limit to the appropriate congresses
  
  nom <- as.data.frame(table(nom$congress,nom$party_code))
    # count up the number of folks in every party in each congress
  
  nom <- nom %>% spread(Var2,Freq); colnames(nom) <- c("cong","dems","reps","oth1","oth2")
    # create congress-level data and label columns appropriately
  
  nom$dem_maj <- ifelse(nom$dems>nom$reps,1,0)
  nom$rep_maj <- ifelse(nom$reps>nom$dems,1,0)
    # create indicators for which party is in the majority
  
  nom <- nom[,c("cong","dem_maj","rep_maj")]
  nom <- nom %>% gather(party,maj,dem_maj,rep_maj)
  nom$party <- gsub("_maj","",fixed=T,nom$party)
    # I also did check to be sure this produced the right values; this is just a nifty
    # not-by-hand way to do it quickly

# add regular old party variable to the main file
  
  mc$party <- ifelse(mc$dem==1,"dem",ifelse(mc$rep==1,"rep","oth"))
  
# merge this information in

  mc <- merge(mc,nom,by=c("cong","party"),all.x=T)

###################################################################################################
# final data processing and output ################################################################
###################################################################################################
  
# we're actually going to drop the veterans' affairs committee; do that here
  
  # first show that these correlations are really quite low
  
  mc_showvet <- mc[,c("state","icpsr","cong","issue","adj.score")] %>% spread(issue,adj.score)
  cor(mc_showvet[,-c(1:3)],use="pairwise.complete.obs")["veterans",]

  # then drop the veterans committee and issue area
  
  mc <- mc[mc$committee!="vet_affairs",]
  
# make a variable for marginality
  
  mc$marginal <- ifelse((mc$dpres>=45 & mc$rep==1) | (mc$dpres<55 & mc$dem==1),1,0)

# make a number of the fixed effects we're going to use

  mc$distid_issue <- paste(mc$distid,mc$issue,sep="_")
  mc$icpsr_issue  <- paste(mc$icpsr,mc$issue,sep="_")
  mc$cong_issue   <- paste(mc$cong,mc$issue,sep="_")
  mc$cong_icpsr   <- paste(mc$cong,mc$icpsr,sep="_")

# we also want to create a measure for how long members
# have served on a committee

  mc$icpsr_committee <- paste(mc$icpsr,mc$committee)
    # start by creating a member-committee factor variable

  oncom <- mc[mc$on_committee==1,]
    # limit the data to folks on committee
  oncom <- aggregate(cong~icpsr_committee,FUN=min,data=oncom)
    # find the first congress a member was on a committee
  colnames(oncom) <- c("icpsr_committee","first_cong")
    # rename columns

  mc <- merge(mc,oncom,by="icpsr_committee",all.x=T)
    # merge that value back into the main data

  mc[is.na(mc$first_cong),"first_cong"] <- 400
    # create a dummy high value for folks who've never been on a committee

  mc$congs_served <- (mc$cong-mc$first_cong)+1
    # find how many congresses since the first time on a committee;
    # we'll call this congs_served, though it doesn't account for possible
    # departures and returns
  
  mc$congs_served[mc$congs_served<0] <- 0
    # here's where we use that silly high dummy value
    
  mc$congs_served <- mc$on_committee*mc$congs_served
    # make sure congs_served only gets counted if you're on the committee
    # at the time

  mc$congs_served[mc$first_cong==83] <- NA
    # finally, there's no way to tell if the first committee in our data is
    # the 83rd whether this was really the first, or just happened to be the
    # first year in our data, so we mark these as NA

  mc$icpsr_committee <- NULL; mc$first_cong <- NULL
    # these are superfluous; drop them

# now create two versions; the main file we'll use is limited to after 1968
# but we also keep and save one with the full period for the exile analysis

  mc_old <- mc
  
  mc <- mc[mc$year>=1968,]

# save both versions

  write.csv(mc_old,"./analysis_data/mc_exile.csv",row.names = F)
  write.csv(mc,"./analysis_data/mc_main.csv",row.names = F)
  write.csv(crs_yearly,"./analysis_data/crs_yearly.csv",row.names=F)

