###################################################################################################
# Legislative Organization and Political Representation ###########################################
# Committee Exile Supplementary Analysis ##########################################################
# Michael Olson and Jon Rogowski ##################################################################
###################################################################################################

###################################################################################################
# working directory and packages ##################################################################
###################################################################################################
  
  require(readxl)
  require(haven)
  require(tidyr)
  require(lfe)
  require(dplyr)
  require(foreign)
  require(stringr)
  require(ggplot2)
  require(stargazer)
  require(vtable)
  require(english)
  
###################################################################################################
# load grimmer and powell data and add icpsr codes from nominate ##################################
###################################################################################################

  gp <- read.csv("./analysis_data/cFinalAllCons.csv")
    gp$Last.Name <- tolower(gp$Last.Name)
    gp <- gp[is.element(gp$State,state.abb),]
    gp <- gp[gp$Incoming.Congress>=83 & gp$Incoming.Congress<=111,]
  
  nom <- read.csv("./raw_data/Hall_members.csv")
    nom <- nom[nom$congress>=min(gp$Outgoing.Congress) & nom$chamber=="House",]
    nom$Last.Name <- tolower(unlist(lapply(str_split(nom$bioname,","),function(x) x[[1]][1])))
    nom <- nom[is.element(nom$party_code,c(100,200)),]
    nom$Party <- ifelse(nom$party_code==200,"R","D")
    nom <- plyr::rename(nom,replace=c("district_code"="District",
                                      "congress"="Incoming.Congress",
                                      "state_abbrev"="State"))
  
  gp <- merge(gp,nom[,c("Incoming.Congress","Last.Name","Party","State","District","icpsr")],by=c("Incoming.Congress","Last.Name","Party","State","District"),all.x=T)
  
    # not everyone matches; first fix people whose districts aren't the same but are definitely the same person
  
    gp_nomatch <- gp[is.na(gp$icpsr),]
    gp_nomatch$icpsr <- NULL
    gp_nomatch <- merge(gp_nomatch,nom[,c("Incoming.Congress","Last.Name","Party","State","District","icpsr")],by=c("Incoming.Congress","Last.Name","Party","State"),all.x=T)
    gp_nomatch$District <- gp_nomatch$District.x
    gp_nomatch[!is.na(gp_nomatch$District.y),"District"] <- gp_nomatch[!is.na(gp_nomatch$District.y),"District.y"]
    gp_nomatch$District.y <- NULL; gp_nomatch$District.x <- NULL
    
  gp <- rbind(gp[!is.na(gp$icpsr),],gp_nomatch)  
  
    # then fix folks whose last names are different; a lot of these are hispanic surnames
    
    gp_nomatch <- gp_nomatch[is.na(gp_nomatch$icpsr),]
    gp_nomatch$icpsr <- NULL
    gp_nomatch <- merge(gp_nomatch,nom[,c("Incoming.Congress","Last.Name","Party","State","District","icpsr")],by=c("Incoming.Congress","District","Party","State"),all.x=T)
    gp_nomatch[is.element(gp_nomatch$Last.Name.x,c("andrews","martinez")),"icpsr"] <- NA
    gp_nomatch$Last.Name.y <- NULL; gp_nomatch <- plyr::rename(gp_nomatch,replace=c("Last.Name.x"="Last.Name"))
    
  gp <- rbind(gp[!is.na(gp$icpsr),],gp_nomatch)
  gp <- gp[!is.na(gp$icpsr),]
    
# now make committee names nice  
  
  gp$committee <- tolower(gp$Committee)
  gp$committee <- gsub(" ","_",fixed=T,gp$committee)
  gp$committee <- gsub("_and_","_",fixed=T,gp$committee)
  
  gp[gp$committee=="banking,_finance,_urban_affairs" | gp$committee=="banking_currency","committee"] <- "banking"
  gp[gp$committee=="education_labor","committee"] <- "educ_labor"
  gp[gp$committee=="veterans'_affairs","committee"] <- "vet_affairs"
  gp[gp$committee=="interstate_foreign_commerce","committee"] <- "energy_commerce"
  
  gp <- gp[gp$Removed==1 & gp$Last.Name!="klink",]
  
###################################################################################################
# load our data and merge into grimmer and powell data ############################################
################################################################################################### 
  
  mc <- read.csv("./analysis_data/mc_exile.csv")
  
# create a lagged DV  
  
  mc <- dplyr::arrange(mc,icpsr,matcher,committee,Issue.Area,cong)
  mc <- DataCombine::slide(data=mc,Var="adj.score",slideBy=-1,NewVar="adj.score.lag",GroupVar="icpsr_issue",TimeVar="cong")
  mc <- dplyr::arrange(mc,icpsr,matcher,committee,Issue.Area,cong)
  mc <- DataCombine::slide(data=mc,Var="on_committee",slideBy=-1,NewVar="on_committee_lag",GroupVar="icpsr_issue",TimeVar="cong")
  mc$comm_cong_party <- paste(mc$cong,mc$committee,mc$party,sep="_")
  
# merge
  
  gp <- gp[is.element(gp$committee,unique(mc$committee)) & gp$Incoming.Congress>=83,]
  
  gp <- merge(gp,mc,by.x=c("Incoming.Congress","committee","icpsr"),by.y=c("cong","committee","icpsr"),all.x=T)
  
  gp <- gp[!is.na(gp$adj.score.lag),] # this drops some folks in the 83rd committee; since that the first year of our scores
                                      # not much we can do. It also loses 2 in the 84th who it appears did serve in the 83rd but
                                      # for whatever reason aren't in the committee data we use.
  gp$comm_cong_party <- paste(gp$Incoming.Congress,gp$committee,gp$party,sep="_")
  comm_cong_parties <- unique(gp$comm_cong_party)
  
  gp <- gp[,c("Incoming.Congress","committee","icpsr","adj.score","adj.score.lag","Removed","rpres","rep")]
  gp <- plyr::rename(gp,replace=c("Incoming.Congress"="cong"))
    
    # so at this point gp is our treated group--all the exiled legislators. now we need to pull out their peers who weren't exiled
  
  control <- mc[is.element(mc$comm_cong_party,comm_cong_parties),] 
    control <- control[control$on_committee==1 & control$on_committee_lag==1 & !is.na(control$on_committee_lag) & !is.na(control$on_committee),]
    control$Removed <- 0
    control <- control[,c("cong","committee","icpsr","adj.score","adj.score.lag","Removed","rpres","rep")]
    
  dat <- rbind(gp,control)  
  
  dat[dat$cong==84 & dat$icpsr==8170,"rpres"] <- .559 # this is connecticut's at-large district, data from wikipedia
  
###################################################################################################
# analysis ########################################################################################
################################################################################################### 
  
  n_exiled <- length(unique(dat[dat$Removed==1,"icpsr"]))
  n_control <- length(unique(dat[dat$Removed==0,"icpsr"]))
  
  fileConn<-file("./results/n_exiled.tex")
  writeLines(as.character(as.english(n_exiled)), fileConn)
  close(fileConn)
  
  fileConn<-file("./results/n_control.tex")
  writeLines(as.character(n_control), fileConn)
  close(fileConn)
  
  mod1 <- felm(adj.score~rpres*Removed+rep|0|0|icpsr,data=dat)
  mod2 <- felm(adj.score~rpres*Removed+rep+adj.score.lag|0|0|icpsr,data=dat)
  mod3 <- felm(adj.score~rpres*Removed+rep+adj.score.lag|committee|0|icpsr,data=dat)
  mod4 <- felm(adj.score~rpres*Removed+adj.score.lag|committee+cong|0|icpsr,data=dat)

  exile_sg <- stargazer(mod1,mod2,mod3,mod4,
                      dep.var.labels = c("Adjusted Conservative Vote Probability"),
                      title="Committee Exile Analysis",
                      label="exile",order=c(1,2,3,5,4,6),
                      covariate.labels = c("Republican Presidential Vote Share",
                                           "Exiled",
                                           "Republican",
                                           "Rep. Pres. Vote Share $\\times$ Exiled",
                                           "Lagged DV",
                                           "Constant"),
                      add.lines = list(c("Committee Fixed Effects","","","\\checkmark","\\checkmark"),
                                       c("Congress Fixed Effects","","","","\\checkmark")),
                      keep.stat = c("n"),
                      star.cutoffs = c(0.10,0.05),star.char = c("*","**"),table.placement="!ht",
                      notes.append = FALSE,notes.label = "",column.sep.width="0pt",
                      table.layout ="-ld-#-t-as-n",
                      notes="\\parbox[t]{0.8\\textwidth}{\\footnotesize \\textit{Note}: Entries are linear regression coefficients with 
                     standard errors clustered by legislator in parentheses. $^{*}$p$<$0.10, $^{**}$p$<$0.05 (two-tailed test).}")
  
  cat(exile_sg, sep = '\n', file = "./results/exile.tex")
  